@@ -16,7 +16,8 @@
 
 template <class sMod, class sPi>
 class sdeMCMC : public sdeLogLik<sMod> {
-  //int nDims2, nCores; // inherited from sdeLogLik
+ private:
+  // inherited from sdeLogLik
   using sdeLogLik<sMod>::nDims2;
   using sdeLogLik<sMod>::nCores;
   int *missInd;
@@ -27,32 +28,37 @@ class sdeMCMC : public sdeLogLik<sMod> {
 		double b, double b2, double *theta,
 		sMod *sde);
  public:
-  //int nComp, nDims, nParams; // inherited from sdeLogLik
+  // inherited from sdeLogLik
   using sdeLogLik<sMod>::nComp;
   using sdeLogLik<sMod>::nDims;
   using sdeLogLik<sMod>::nParams;
-  double *currFull, *propFull, *propAccept;
-  double *currX, *propX, *currTheta, *propTheta;
-  double *propU; // for acceptance rates (predrawn in parallel version)
-  //double *dT, *sqrtDT; // inherited from sdeLogLik
   using sdeLogLik<sMod>::dT;
   using sdeLogLik<sMod>::sqrtDT;
-  double *B, *sqrtB;
-  int *nObsComp;
-  bool *fixedTheta;
-  //sMod *sde; // inherited sdeLogLik
-  using sdeLogLik<sMod>::sde;
-  // double *propMean, *propSd, *propZ; // inherited from sdeLogLik
   using sdeLogLik<sMod>::propMean;
   using sdeLogLik<sMod>::propSd;
   using sdeLogLik<sMod>::propZ;
-  // double loglik(double *theta, double *x); // inherited from sdeLogLik
+  using sdeLogLik<sMod>::nObsComp;
+  using sdeLogLik<sMod>::sde;
   using sdeLogLik<sMod>::loglik;
+  /// space for full (complete data + params) current MCMC state and proposal states
+  double *currFull, *propFull;
+  /// separate pointers for data and params
+  double *currX, *propX, *currTheta, *propTheta;
+  /// space for simultaneous acceptance rates (predrawn in parallel version)
+  double *propAccept, *propU;
+  /// shrinkage factors for Eraker proposals
+  double *B, *sqrtB;
+  // int *nObsComp; ///< number of observed dimensions per observation
+  bool *fixedTheta; ///< whether or not each parameter gets updated
+  /// missing data updates
   void missGibbsUpdate(double *jumpSd, int *gibbsAccept, int *paramAccept);
+  /// parameter updates
   void paramVanillaUpdate(double *jumpSd, int *paramAccept);
+  /// constructor
   sdeMCMC(int n, double *dt, double *xInit, double *thetaInit,
 	  int *xIndex, bool *thetaIndex,
 	  double **phi, int nArgs, int *nEachArg, int ncores);
+  /// destructor
   ~sdeMCMC();
 };
 
@@ -63,19 +69,32 @@ template <class sMod, class sPi>
 				     double **phi,
 				     int nArgs, int *nEachArg,
 				     int ncores) :
-  sdeLogLik<sMod>(n, dt, ncores) {
+  sdeLogLik<sMod>(n, dt, xIndex, ncores) {
   int ii, jj;
-  int nDims2, nCores; // inherited from sdeLogLik
-  int nComp, nDims, nParams; // inherited from sdeLogLik
-  double *dT, *sqrtDT; // inherited from sdeLogLik
-  // inherited template parameters
-  nDims2 = this->nDims2;
-  nCores = this->nCores;
-  nComp = this->nComp;
-  nDims = this->nDims;
-  nParams = this->nParams;
-  dT = this->dT;
-  sqrtDT = this->sqrtDT;
+  /// inherited from sdeLogLik
+  // int nDims2 = this->nDims2;
+  // int nCores = this->nCores;
+  // int nComp = this->nComp;
+  // int nDims = this->nDims;
+  // int nParams = this->nParams;
+  // double *dT = this->dT;
+  // double *sqrtDT = this->sqrtDT;
+  // double *propMean = this->propMean;
+  // double *propSd = this->propSd;
+  // double *propZ = this->propZ;
+  // int *nObsComp = this->nObsComp;
+  // sMod *sde = this->sde;
+  // int nDims2, nCores; // inherited from sdeLogLik
+  // int nComp, nDims, nParams; // inherited from sdeLogLik
+  // double *dT, *sqrtDT; // inherited from sdeLogLik
+  // // inherited template parameters
+  // nDims2 = this->nDims2;
+  // nCores = this->nCores;
+  // nComp = this->nComp;
+  // nDims = this->nDims;
+  // nParams = this->nParams;
+  // dT = this->dT;
+  // sqrtDT = this->sqrtDT;
   // memory allocation
   B = new double[nComp];
   sqrtB = new double[nComp];
@@ -93,10 +112,10 @@ template <class sMod, class sPi>
   propU = new double[nComp];
   currX = currFull + nParams;
   propX = propFull + nParams;
-  nObsComp = new int[nComp];
+  // nObsComp = new int[nComp];
   // initialize
   for(ii=0; ii<nComp; ii++) {
-    nObsComp[ii] = xIndex[ii];
+    // nObsComp[ii] = xIndex[ii];
     propU[ii] = 0.0;
     for(jj=0; jj<nDims; jj++) {
       currX[ii*nDims + jj] = xInit[ii*nDims + jj];
@@ -148,7 +167,7 @@ inline sdeMCMC<sMod, sPi>::~sdeMCMC() {
   delete [] propAccept;
   delete [] propU;
   delete [] missInd;
-  delete [] nObsComp;
+  // delete [] nObsComp;
   delete [] fixedTheta;
   delete prior;
 }
