@@ -1,6 +1,8 @@
 // export sample models
 
-#include <Rcpp.h>
+// #include <Rcpp.h>
+//[[Rcpp::depends("RcppArmadillo")]]
+#include <RcppArmadillo.h>
 using namespace Rcpp;
 #include "sdeInterface.h"
 namespace mvn {
@@ -23,6 +25,10 @@ namespace pgnet {
 #include "pgnetModel.h"
 #undef sdeModel_h
 }
+namespace eou {
+#include "eouModel.h"
+#undef eouModel_h
+}
 
 //[[Rcpp::export(".hest_MakeModel")]]
 SEXP hestMakeModel() {
@@ -51,3 +57,10 @@ SEXP lotvolMakeModel() {
   XPtr<sdeCobj> sdeptr(sde, true);
   return sdeptr;
 }
+
+//[[Rcpp::export(".eou_MakeModel")]]
+SEXP eouMakeModel() {
+  sdeCobj *sde = new sdeRobj<eou::sdeModel, mvn::sdePrior>;
+  XPtr<sdeCobj> sdeptr(sde, true);
+  return sdeptr;
+}
